addtest: Add a test set to ada

addtestR Documentation

Add a test set to ada

Description

addtest updates the ada object to have additional testing errors and testing kappa accuracies for each iteration.

Usage

  addtest(x,test.x,test.y, ...)

Arguments

x

object generated by the function ada.

test.x

new x data

test.y

the true labeling for this testing data

...

other arguments not used by this function.

Value

updated ada object.

See Also

ada,update.ada


ada documentation built on Feb. 17, 2026, 9:07 a.m.

Related to addtest in ada...