| update.ada | R Documentation |
ada.update updates the ada object to have additional trees given a new number of
iterations.
## S3 method for class 'ada'
update(object, x, y, test.x, test.y = NULL, n.iter, ...)
object |
object generated by the function |
x |
x training data |
y |
training response |
test.x |
x testing data (optional) |
test.y |
the true labeling for this testing data (optional) |
n.iter |
new number of iterations, must be provided and n.iter>iter |
... |
other arguments not used by this function. |
updated ada object.
ada.default,summary.ada,predict.ada,
plot.ada,pairs.ada
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.